@@ -614,6 +614,7 @@ class Ports:
         now = datetime.now()
         exp = now + datetime.timedelta(seconds = expiry)
         x = f"Set-Cookie: {name}={value}; Expires={exp}; Path={Ports.path}"
+      Ports.headers.append(x)
       
       
 
@@ -628,37 +629,41 @@ class Ports:
 
       Ports.headers.append(x)
     def get_all():
-      cookies = {}
+      cookiez = {}
       cookiejar = Ports.cookiejar
       cookiejar = "".join(cookiejar)
       cookiejar = cookiejar.split("; ")
 
+      
+
       for cookie in cookiejar:
-        if cookiejar == ['']:
+        if cookiejar == [''] or cookiejar == []:
           return "No Cookies stored"
         
         cks = cookie.split("=")
         name = cks[0]
         value = cks[1]
-        cookies[name] = value
-    def get(name):
-      cookies = {}
+        cookiez[name] = value
+      return cookiez
+    def get(namer):
+      cookiez = {}
 
       cookiejar = Ports.cookiejar
       cookiejar = "".join(cookiejar)
       cookiejar = cookiejar.split("; ")
 
+
       for cookie in cookiejar:
-        if cookiejar == ['']:
+        if cookiejar == [''] or cookiejar == []:
           return "No Cookies stored"
         
         cks = cookie.split("=")
         name = cks[0]
         value = cks[1]
-        cookies[name] = value
-      if name not in cookies:
+        cookiez[name] = value
+      if namer not in cookiez:
         return "Cookie not found"
-      return str(cookies[name])
+      return str(cookiez[namer])
 
 
 
